@@ -5,8 +5,9 @@ from . import (activity_feed, authentication_tokens, cookie_cutters, dashboard,
                environments, fact_type_enums, fact_type_ranges, fact_types,
                groups, integrations, metrics, namespaces, openapi, opensearch,
                operations_log, permissions, project_activity_feed,
-               project_dependencies, project_fact_types, project_facts,
-               project_link_types, project_links, project_score_history,
+               project_dependencies, project_fact_history, project_fact_types,
+               project_facts, project_link_types, project_links,
+               project_notes, project_score_history, project_secrets,
                project_types, project_urls, projects, reports, status, ui)
 
 URLS = [
@@ -85,6 +86,9 @@ URLS = [
     web.url(r'^/projects/(?P<project_id>\d+)/fact-types$',
             project_fact_types.CollectionRequestHandler,
             name='project-fact-types'),
+    web.url(r'^/projects/(?P<project_id>\d+)/fact-history$',
+            project_fact_history.CollectionRequestHandler,
+            name='project-fact-history'),
     web.url(r'^/projects/(?P<project_id>\d+)/feed$',
             project_activity_feed.CollectionRequestHandler,
             name='project-activity-feed'),
@@ -95,9 +99,18 @@ URLS = [
             r'(?P<link_type_id>\d+)$',
             project_links.RecordRequestHandler,
             name='project-link'),
+    web.url(r'^/projects/(?P<project_id>\d+)/notes$',
+            project_notes.CollectionRequestHandler,
+            name='project-notes'),
+    web.url(r'^/projects/(?P<project_id>\d+)/notes/(?P<id>\d+)$',
+            project_notes.RecordHandler,
+            name='project-note'),
     web.url(r'^/projects/(?P<project_id>\d+)/score-history$',
             project_score_history.CollectionRequestHandler,
             name='project-score-history'),
+    web.url(r'^/projects/(?P<project_id>\d+)/secrets$',
+            project_secrets.CollectionRequestHandler,
+            name='project-secrets'),
     web.url(r'^/projects/(?P<project_id>\d+)/urls$',
             project_urls.CollectionRequestHandler,
             name='project-urls'),
